@@ -1,6 +1,5 @@
 """KIM properties object serialization."""
 
-import os
 from os.path import abspath, join, isdir, pardir, isfile, dirname
 from io import BytesIO
 import pickle
@@ -43,8 +42,8 @@ def pickle_kim_properties(properties=None,
         # KIM property files.
         kim_property_files = []
 
-        # KIM property files path
-        # An absolute path (or a valid relative path) to the KIM property files folder.
+        # KIM property files path. An absolute path (or a valid relative path)
+        # to the KIM property files folder.
         kim_property_files_path = join(dirname(abspath(__file__)),
                                        pardir,
                                        "external",
@@ -139,7 +138,7 @@ def pickle_kim_properties(properties=None,
             "tag:staff@noreply.openkim.org,2014-04-15:property/configuration-nonorthogonal-periodic-3d-cell-relaxed-particles-fixed",
             "tag:staff@noreply.openkim.org,2014-04-15:property/configuration-nonorthogonal-periodic-3d-cell-relaxed-particles-relaxed",
             "tag:staff@noreply.openkim.org,2015-10-12:property/configuration-periodic-2d-cell-fixed-particles-fixed",
-            "tag:staff@noreply.openkim.org,2019-07-24:property/dislocation-core-energy-cubic-crystal-npt",
+            "tag:staff@noreply.openkim.org,2021-02-24:property/dislocation-core-energy-cubic-crystal-npt",
             "tag:staff@noreply.openkim.org,2016-05-24:property/elastic-constants-first-strain-gradient-isothermal-cubic-crystal-npt",
             "tag:staff@noreply.openkim.org,2016-05-24:property/elastic-constants-first-strain-gradient-isothermal-monoatomic-hexagonal-crystal-npt",
             "tag:staff@noreply.openkim.org,2014-05-21:property/elastic-constants-isothermal-cubic-crystal-npt",
@@ -188,22 +187,22 @@ def pickle_kim_properties(properties=None,
                 msg += '"\ncan not be found!'
                 raise KIMPropertyError(msg)
 
-        del(kim_property_files_path)
+        del kim_property_files_path
 
         # KIM properties dictionary indexed by properties full IDs.
         kim_properties = {k: kim_edn.load(v) for k, v in zip(
             kim_property_ids, kim_property_files)}
 
         # KIM properties name to full ID dictionary.
-        property_name_to_property_id = {
-            k: v for k, v in zip(kim_property_names, kim_property_ids)}
+        property_name_to_property_id = \
+            dict(zip(kim_property_names, kim_property_ids))
 
         # KIM properties full ID to name dictionary.
-        property_id_to_property_name = {
-            k: v for k, v in zip(kim_property_ids, kim_property_names)}
+        property_id_to_property_name = \
+            dict(zip(kim_property_ids, kim_property_names))
 
-        del(kim_property_names)
-        del(kim_property_ids)
+        del kim_property_names
+        del kim_property_ids
 
         kim_properties_list = [
             kim_properties,
@@ -211,7 +210,7 @@ def pickle_kim_properties(properties=None,
             property_id_to_property_name,
         ]
     else:
-        if not (isinstance(properties, dict)):
+        if not isinstance(properties, dict):
             msg = 'wrong input, "properties" is not a `dict`.'
             raise KIMPropertyError(msg)
 
@@ -219,7 +218,7 @@ def pickle_kim_properties(properties=None,
             msg = 'wrong input, "properties" is empty.'
             raise KIMPropertyError(msg)
 
-        property_ids = [k for k in properties]
+        property_ids = list(properties.keys())
 
         property_names = []
         for _id in property_ids:
@@ -227,15 +226,13 @@ def pickle_kim_properties(properties=None,
             property_names.append(_name)
 
         # KIM properties name to full ID dictionary.
-        name_to_property_id = {
-            k: v for k, v in zip(property_names, property_ids)}
+        name_to_property_id = dict(zip(property_names, property_ids))
 
         # KIM properties full ID to name dictionary.
-        id_to_property_name = {
-            k: v for k, v in zip(property_ids, property_names)}
+        id_to_property_name = dict(zip(property_ids, property_names))
 
-        del(property_names)
-        del(property_ids)
+        del property_names
+        del property_ids
 
         kim_properties_list = [
             properties,
@@ -256,7 +253,8 @@ def pickle_kim_properties(properties=None,
             raise KIMPropertyError(msg)
 
 
-def unpickle_kim_properties(fp=join(kim_properties_path, 'kim_properties.pickle')):
+def unpickle_kim_properties(fp=join(kim_properties_path,
+                                    'kim_properties.pickle')):
     """Deserialize KIM properties.
 
     Return reconstituted object hierarchy from the pickled object. Read the
@@ -284,10 +282,10 @@ def unpickle_kim_properties(fp=join(kim_properties_path, 'kim_properties.pickle'
         msg += 'If "fp" refers to a file name, make sure it exists in PATH '
         msg += 'or provide the file name with its absolute PATH.'
         raise KIMPropertyError(msg)
-    else:
-        try:
-            f = BytesIO(fp)
-            return pickle.load(f)
-        except:
-            msg = 'wrong input. Neither can open nor load the input.'
-            raise KIMPropertyError(msg)
+
+    try:
+        f = BytesIO(fp)
+        return pickle.load(f)
+    except:
+        msg = 'wrong input. Neither can open nor load the input.'
+        raise KIMPropertyError(msg)
