@@ -1,8 +1,5 @@
-import os
 from os.path import join, isfile
 
-import kim_edn
-
 from tests.test_kim_property import PyTest
 
 
